@@ -9,8 +9,8 @@ summary.splmm <- function(object,...)
       } else {
         
     # 1. part
-    table1 <- round(c(object$aic,object$bic,object$bbic,object$ebic,object$logLik,object$deviance,object$objective),1)
-    names(table1) <- c("AIC","BIC","BBIC","EBIC","logLik","deviance","objective")
+    table1 <- round(c(object$aic,object$bic,object$bicc,object$ebic,object$logLik,object$deviance,object$objective),1)
+    names(table1) <- c("AIC","BIC","BICC","EBIC","logLik","deviance","objective")
     cat("Model fitted by",object$method,"for","lambda1 =",round(object$lambda1,3),",lambda2 =",round(object$lambda2,3),":\n")
     print(table1)
     
@@ -25,7 +25,7 @@ summary.splmm <- function(object,...)
     
     if (is.null(xnames))
     {
-      rownames(table3) <- c("(Intercept)",paste("X", 2:length(object$coefficients),sep=""))
+      rownames(table3) <- c("(Intercept)",paste("X", 1:(length(object$coefficients)-1),sep=""))
     } else
     {
       rownames(table3) <- c("(Intercept)",colnames(object$data$x)[-1]) 	
@@ -52,7 +52,7 @@ summary.splmm <- function(object,...)
 
     if (is.null(znames))
       {
-        rownames(matrixVar) <-c("(Intercept)",paste("Z", 2:nrow(object$D),sep=""),"")
+        rownames(matrixVar) <-c("(Intercept)",paste("Z", 1:(nrow(object$D)-1),sep=""),"")
       } else
       {
         rownames(matrixVar) <- c("(Intercept)",colnames(object$data$z)[-1],"sigma") 	
@@ -103,11 +103,11 @@ plot.splmm <- function(x,...){
     names(BIC) = c("lambda1","Criteria","Value")
     AIC = cbind.data.frame(x$lam1.seq,rep("AIC",length(x$AIC.lam1)),x$AIC.lam1)
     names(AIC) = c("lambda1","Criteria","Value")
-    BBIC = cbind.data.frame(x$lam1.seq,rep("BBIC",length(x$BBIC.lam1)),x$BBIC.lam1)
-    names(BBIC) = c("lambda1","Criteria","Value")
-    EBIC = cbind.data.frame(x$lam1.seq,rep("EIC",length(x$EBIC.lam1)),x$EBIC.lam1)
+    BICC = cbind.data.frame(x$lam1.seq,rep("BICC",length(x$BICC.lam1)),x$BICC.lam1)
+    names(BICC) = c("lambda1","Criteria","Value")
+    EBIC = cbind.data.frame(x$lam1.seq,rep("EBIC",length(x$EBIC.lam1)),x$EBIC.lam1)
     names(EBIC) = c("lambda1","Criteria","Value")
-    plot.df = rbind.data.frame(BIC,AIC,BBIC,EBIC)
+    plot.df = rbind.data.frame(BIC,AIC,BICC,EBIC)
     plot.df$Value = round(plot.df$Value,2)
     
     ggplot(plot.df, aes(x = lambda1, y = Value, group = Criteria)) +
@@ -121,11 +121,11 @@ plot.splmm <- function(x,...){
     names(BIC) = c("lambda2","Criteria","Value")
     AIC = cbind.data.frame(x$lam2.seq,rep("AIC",length(x$AIC.lam2)),x$AIC.lam2)
     names(AIC) = c("lambda2","Criteria","Value")
-    BBIC = cbind.data.frame(x$lam2.seq,rep("BBIC",length(x$BBIC.lam2)),x$BBIC.lam2)
-    names(BBIC) = c("lambda1","Criteria","Value")
-    EBIC = cbind.data.frame(x$lam2.seq,rep("EIC",length(x$EBIC.lam2)),x$EBIC.lam2)
-    names(EBIC) = c("lambda1","Criteria","Value")
-    plot.df = rbind.data.frame(BIC,AIC,BBIC,EBIC)
+    BICC = cbind.data.frame(x$lam2.seq,rep("BICC",length(x$BICC.lam2)),x$BICC.lam2)
+    names(BICC) = c("lambda2","Criteria","Value")
+    EBIC = cbind.data.frame(x$lam2.seq,rep("EBIC",length(x$EBIC.lam2)),x$EBIC.lam2)
+    names(EBIC) = c("lambda2","Criteria","Value")
+    plot.df = rbind.data.frame(BIC,AIC,BICC,EBIC)
     plot.df$Value = round(plot.df$Value,2)
     
     
@@ -139,22 +139,22 @@ plot.splmm <- function(x,...){
     names(BIC1) = c("lambda1","Criteria","Value")
     AIC1 = cbind.data.frame(x$lam1.seq,rep("AIC",length(x$AIC.lam1)),x$AIC.lam1)
     names(AIC1) = c("lambda1","Criteria","Value")
-    BBIC1 = cbind.data.frame(x$lam1.seq,rep("BBIC",length(x$BBIC.lam1)),x$BBIC.lam1)
-    names(BBIC1) = c("lambda1","Criteria","Value")
+    BICC1 = cbind.data.frame(x$lam1.seq,rep("BICC",length(x$BICC.lam1)),x$BICC.lam1)
+    names(BICC1) = c("lambda1","Criteria","Value")
     EBIC1 = cbind.data.frame(x$lam1.seq,rep("EBIC",length(x$EBIC.lam1)),x$EBIC.lam1)
     names(EBIC1) = c("lambda1","Criteria","Value")
-    plot.df1 = rbind.data.frame(BIC1,AIC1,BBIC1,EBIC1)
+    plot.df1 = rbind.data.frame(BIC1,AIC1,BICC1,EBIC1)
     plot.df1$Value = round(plot.df1$Value,2)
     
     BIC2 = cbind.data.frame(x$lam2.seq,rep("BIC",length(x$BIC.lam2)),x$BIC.lam2)
     names(BIC2) = c("lambda2","Criteria","Value")
     AIC2 = cbind.data.frame(x$lam2.seq,rep("AIC",length(x$AIC.lam2)),x$AIC.lam2)
     names(AIC2) = c("lambda2","Criteria","Value")
-    BBIC2 = cbind.data.frame(x$lam2.seq,rep("BBIC",length(x$BBIC.lam2)),x$BBIC.lam2)
-    names(BBIC2) = c("lambda2","Criteria","Value")
+    BICC2 = cbind.data.frame(x$lam2.seq,rep("BICC",length(x$BICC.lam2)),x$BICC.lam2)
+    names(BICC2) = c("lambda2","Criteria","Value")
     EBIC2 = cbind.data.frame(x$lam2.seq,rep("EBIC",length(x$EBIC.lam2)),x$EBIC.lam2)
     names(EBIC2) = c("lambda2","Criteria","Value")
-    plot.df2 = rbind.data.frame(BIC2,AIC2,BBIC2,EBIC2)
+    plot.df2 = rbind.data.frame(BIC2,AIC2,BICC2,EBIC2)
     plot.df2$Value = round(plot.df2$Value,2)
     
     
@@ -176,7 +176,7 @@ plot.splmm <- function(x,...){
   
 }
 
-plot3D.splmm <- function(x,criteria=c("BIC","AIC","BBIC","EBIC"),type=c("line","surface"),...){
+plot3D.splmm <- function(x,criteria=c("BIC","AIC","BICC","EBIC"),type=c("line","surface"),...){
   # check if the object is splmm.tuning
   if(class(x)!="splmm.tuning") stop("input is not splmm.tuning object.")
   if(!x$lam1.tuning|!x$lam2.tuning) stop("input needs to be splmm.tuning object for both lam1 and lam2.")
@@ -198,12 +198,12 @@ plot3D.splmm <- function(x,criteria=c("BIC","AIC","BBIC","EBIC"),type=c("line","
       scatter3D(x=AIC.df$`lambda 1`, y=AIC.df$`lambda 2`, z=AIC.df$Value, phi = 0, bty = "g",  type = "h", 
                 ticktype = "detailed", pch = 19, cex = 0.5, xlab="lambda 1",ylab="lambda 2",zlab="",main="AIC value")
       
-    }else if(criteria=="BBIC"){
-      BBIC.df = cbind.data.frame(expand.grid(x$lam1.seq,x$lam2.seq),as.vector(x$fit.BBIC))
-      names(BBIC.df) = c("lambda 1","lambda 2","Value")
+    }else if(criteria=="BICC"){
+      BICC.df = cbind.data.frame(expand.grid(x$lam1.seq,x$lam2.seq),as.vector(x$fit.BICC))
+      names(BICC.df) = c("lambda 1","lambda 2","Value")
       
-      scatter3D(x=BBIC.df$`lambda 1`, y=BBIC.df$`lambda 2`, z=BBIC.df$Value, phi = 0, bty = "g",  type = "h", 
-                ticktype = "detailed", pch = 19, cex = 0.5, xlab="lambda 1",ylab="lambda 2",zlab="",main="BBIC value")
+      scatter3D(x=BICC.df$`lambda 1`, y=BICC.df$`lambda 2`, z=BICC.df$Value, phi = 0, bty = "g",  type = "h", 
+                ticktype = "detailed", pch = 19, cex = 0.5, xlab="lambda 1",ylab="lambda 2",zlab="",main="BICC value")
     }else if(criteria=="EBIC"){
       EBIC.df = cbind.data.frame(expand.grid(x$lam1.seq,x$lam2.seq),as.vector(x$fit.EBIC))
       names(EBIC.df) = c("lambda 1","lambda 2","Value")
@@ -226,12 +226,12 @@ plot3D.splmm <- function(x,criteria=c("BIC","AIC","BBIC","EBIC"),type=c("line","
               xlab = "lambda 1", ylab = "lambda 2", 
               zlab = "", main = "AIC value")
       
-    }else if(criteria=="BBIC"){
+    }else if(criteria=="BICC"){
       persp3D(x = x$lam1.seq, y = x$lam2.seq, 
-              z = x$fit.BBIC, phi = 0, bty = "g", type = "h", 
+              z = x$fit.BICC, phi = 0, bty = "g", type = "h", 
               ticktype = "detailed", pch = 19, cex = 0.5, 
               xlab = "lambda 1", ylab = "lambda 2", 
-              zlab = "", main = "BBIC value")
+              zlab = "", main = "BICC value")
     }else if(criteria=="EBIC"){
       persp3D(x = x$lam1.seq, y = x$lam2.seq, 
               z = x$fit.EBIC, phi = 0, bty = "g", type = "h", 
